@@ -32,22 +32,14 @@
 # define PTYTTY_REENTRANT 1
 #endif
 
-/*
- * Provide a STL-like vector class and find algorithm.
- * The default below is fine for normal C++ environments.
- */
-#ifndef PTYTTY_NO_LIBCPP
-# define PTYTTY_NO_LIBCPP 0
-#endif
-
 /*
  * printf-like functions to be called on fatal conditions
  * (must exit), or warning conditions (only print message)
  */
 #ifndef PTYTTY_FATAL
-#define PTYTTY_FATAL(msg) do { PTYTTY_WARN ("%s", msg); _exit (1); } while (0)
+#define PTYTTY_FATAL(msg) do { PTYTTY_WARN (msg); _exit (1); } while (0)
 #endif
 #ifndef PTYTTY_WARN
-#define PTYTTY_WARN(msg,arg) fprintf (stderr, msg, arg)
+#define PTYTTY_WARN(msg) fputs (msg, stderr)
 #endif
 
